// SPDX-License-Identifier: UNLICENSED
pragma solidity 0.8.23;

import "@openzeppelin/token/ERC20/ERC20.sol";
import "@openzeppelin/utils/cryptography/MerkleProof.sol";

contract TokenDistributor {
    event Distributed(address[] recipients, uint256[] amounts, uint256 nextDistribution);

    address public owner;
    IERC20 public sirioToken;
    uint256 public duration;
    uint256 public nextDistribution;

    constructor(address _sirioToken, uint256 _duration) {
        require(_sirioToken != address(0), "Invalid address");
        require(_duration > 0, "Invalid duration");

        owner = msg.sender;
        sirioToken = IERC20(_sirioToken);

        duration = _duration;
        nextDistribution = block.timestamp + _duration;
    }

    modifier onlyOwner() {
        require(msg.sender == owner, "Only owner can call this function");
        _;
    }

    /**
     * @dev Distribute tokens to multiple recipients.
     */
    function distribute(address[] calldata _recipients, uint256[] calldata _amounts) external onlyOwner {
        require(block.timestamp >= nextDistribution, "Distribution not allowed yet");
        require(_recipients.length == _amounts.length, "Invalid input");


        nextDistribution = block.timestamp + duration;
        for (uint256 i = 0; i < _recipients.length; ++i) {
            require(_recipients[i] != address(0), "Invalid recipient");
            require(_amounts[i] > 0, "Invalid amount");
            require(sirioToken.allowance(msg.sender, address(this)) >= _amounts[i], "Insufficient allowance");
            bool success = sirioToken.transferFrom(msg.sender, _recipients[i], _amounts[i]);
            require(success, "Transfer failed");
        }

        emit Distributed(_recipients, _amounts, nextDistribution);
    }
}
